antiSMASH object model
======================
[![Build Status](https://github.drone.secondarymetabolites.org/api/badges/antismash/models/status.svg)](https://github.drone.secondarymetabolites.org/antismash/models)

An object model for mapping antiSMASH data objects from and to Redis via aioredis.


License
-------

Under the same GNU AGPL v3 or later license as the rest of antiSMASH.
See [`LICENSE.txt`](LICENSE.txt) for details.
